@@ -36,17 +36,17 @@ float TitleFontSize = 12;
    General purpose cluster analysis program.  Written with flexibility
    in mind rather than all out efficiency.  
 
-   Copyright(c) G. J. Barton (1993,1997)
+   Copyright(c) G. J. Barton (1993,1997,2002)
 
-   Author: G. J. Barton (June 1993)
-   Laboratory of Molecular Biophysics
-   Rex Richards Building
-   South Parks Road
-   Oxford OX1 3QU
-   UK.
-
-   email:  geoff.barton@ox.ac.uk
+   Author: G. J. Barton 
+   School of Life Sciences
+   University of Dundee
+   Dow St.
+   Dundee DD1 5EH
+   Scotland
 
+   email:geoff@compbio.dundee.ac.uk
+   
    Example input file:
 
 7 
@@ -86,6 +86,8 @@ are equivalent to the full tree method.  GJB.
 
 15/12/93:  Correct bug in definition of VERY_SMALL  ie now = -DBL_MAX.  This 
 allows the complete and means linkage to work with negative numbers.
+
+4 August 2002:  Update affiliation and also add gjnoc2 routine to the distribution.
 ----------------------------------------------------------------------------*/
 
 main(int argc,char *argv[])
@@ -209,8 +211,8 @@ main(int argc,char *argv[])
 	  }
 	  }else{
 	    fprintf(std_err,"Cluster analysis program\n\n");
-	    fprintf(std_err,"Author:  G. J. Barton, University of Oxford, UK\n");
-	    fprintf(std_err,"Copyright:  G. J. Barton and University of Oxford (1993)\n\n");
+	    fprintf(std_err,"Author:  G. J. Barton, University of Dundee, UK\n");
+	    fprintf(std_err,"Copyright:  G. J. Barton (1993,1997,2002)\n\n");
 	    fprintf(std_err,"Please cite: OC a cluster analysis program, Barton, G. J.  1993\n\n");
 	    fprintf(std_err,"Usage: oc <sim/dis> <single/complete/means> <ps> <cut N>\n\n");
 	    fprintf(std_err,"Version 1.0 - Requires a file to be piped to standard input\n");
